@@ -1,4 +1,4 @@
-//@line 38 "/export/home/mozilla/uild/firefox2.0/mozilla/browser/components/feeds/src/WebContentConverter.js"
+//@line 38 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/feeds/src/WebContentConverter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -24,6 +24,9 @@ const PREF_SELECTED_WEB = "browser.feeds.handlers.webservice";
 const PREF_SELECTED_ACTION = "browser.feeds.handler";
 const PREF_SELECTED_READER = "browser.feeds.handler.default";
 
+const NS_ERROR_MODULE_DOM = 2152923136;
+const NS_ERROR_DOM_SYNTAX_ERR = NS_ERROR_MODULE_DOM + 12;
+
 function WebContentConverter() {
 }
 WebContentConverter.prototype = {
@@ -340,7 +343,7 @@ var WebContentConverterRegistrar = {
    */
   registerProtocolHandler: 
   function WCCR_registerProtocolHandler(protocol, uriString, title, contentWindow) {
-//@line 390 "/export/home/mozilla/uild/firefox2.0/mozilla/browser/components/feeds/src/WebContentConverter.js"
+//@line 393 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/feeds/src/WebContentConverter.js"
   },
 
   /**
@@ -355,8 +358,14 @@ var WebContentConverterRegistrar = {
 
     try {
       var uri = this._makeURI(uriString);
+    } catch (ex) {
+      // not supposed to throw according to spec
+      return; 
     }
-    catch(ex) { return; }
+
+    // If the uri doesn't contain '%s', it won't be a good content handler
+    if (uri.spec.indexOf("%s") < 0)
+      throw NS_ERROR_DOM_SYNTAX_ERR;
 
     // For security reasons we reject non-http(s) urls (see bug Bug 354316),
     // we may need to revise this once we support more content types
@@ -364,6 +373,8 @@ var WebContentConverterRegistrar = {
       throw("Permission denied to add " + uri.spec + "as a content handler");
 
     // XXXben - for Firefox 2 we only support feed types
+    // XXX this should be a "security exception" according to spec, but that
+    // isn't defined yet.
     contentType = this._resolveContentType(contentType);
     if (contentType != TYPE_MAYBE_FEED)
       return;    
@@ -718,7 +729,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/export/home/mozilla/uild/firefox2.0/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 44 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 
 var gTraceOnAssert = true;
 
@@ -743,37 +754,10 @@ function NS_ASSERT(condition, message) {
   if (condition)
     return;
 
-  var caller = arguments.callee.caller;
   var assertionText = "ASSERT: " + message + "\n";
-  dump(assertionText);
 
-  var stackText = "";
-  if (gTraceOnAssert) {
-    stackText = "Stack Trace: \n";
-    var count = 0;
-    while (caller) {
-      stackText += count++ + ":" + caller.name + "(";
-      for (var i = 0; i < caller.arguments.length; ++i) {
-        var arg = caller.arguments[i];
-        stackText += arg;
-        if (i < caller.arguments.length - 1)
-          stackText += ",";
-      }
-      stackText += ")\n";
-      caller = caller.arguments.callee.caller;
-    }
-  }
-
-  var environment = Components.classes["@mozilla.org/process/environment;1"].
-                    getService(Components.interfaces.nsIEnvironment);
-  if (environment.exists("XUL_ASSERT_PROMPT") &&
-      !parseInt(environment.get("XUL_ASSERT_PROMPT")))
-    return;
-
-  var source = null;
-  if (this.window)
-    source = window;
-  var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].
-           getService(Components.interfaces.nsIPromptService);
-  ps.alert(source, "Assertion Failed", assertionText + stackText);
+//@line 72 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+  Components.util.reportError(assertionText);
+  return;
+//@line 108 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 }
