@@ -49,6 +49,7 @@ const nsIDOMChromeWindow     = Components.interfaces.nsIDOMChromeWindow;
 const nsIDOMWindow           = Components.interfaces.nsIDOMWindow;
 const nsIFactory             = Components.interfaces.nsIFactory;
 const nsIFileURL             = Components.interfaces.nsIFileURL;
+const nsIJARURI              = Components.interfaces.nsIJARURI;
 const nsIHttpProtocolHandler = Components.interfaces.nsIHttpProtocolHandler;
 const nsIInterfaceRequestor  = Components.interfaces.nsIInterfaceRequestor;
 const nsIPrefBranch          = Components.interfaces.nsIPrefBranch;
@@ -61,6 +62,7 @@ const nsIWindowWatcher       = Components.interfaces.nsIWindowWatcher;
 const nsICategoryManager     = Components.interfaces.nsICategoryManager;
 const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
+const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
 
 const NS_BINDING_ABORTED = 0x804b0002;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
@@ -106,28 +108,35 @@ function resolveURIInternal(aCmdLine, aArgument) {
   return uri;
 }
 
+const OVERRIDE_NONE        = 0;
+const OVERRIDE_NEW_PROFILE = 1;
+const OVERRIDE_NEW_MSTONE  = 2;
+/**
+ * Determines whether a home page override is needed.
+ * Returns:
+ *  OVERRIDE_NEW_PROFILE if this is the first run with a new profile.
+ *  OVERRIDE_NEW_MSTONE if this is the first run with a build with a different
+ *                      Gecko milestone (i.e. right after an upgrade).
+ *  OVERRIDE_NONE otherwise.
+ */
 function needHomepageOverride(prefb) {
-  var savedmstone;
+  var savedmstone = null;
   try {
     savedmstone = prefb.getCharPref("browser.startup.homepage_override.mstone");
-  }
-  catch (e) {
-  }
+  } catch (e) {}
 
   if (savedmstone == "ignore")
-    return 0;
+    return OVERRIDE_NONE;
 
   var mstone = Components.classes["@mozilla.org/network/protocol;1?name=http"]
                          .getService(nsIHttpProtocolHandler).misc;
 
   if (mstone != savedmstone) {
     prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
-    // Return 1 if true if the pref didn't exist (i.e. new profile) or 2 for an upgrade
-    return (savedmstone ? 2 : 1);
+    return (savedmstone ? OVERRIDE_NEW_MSTONE : OVERRIDE_NEW_PROFILE);
   }
-  
-  // Return 0 if not a new profile and not an upgrade
-  return 0;
+
+  return OVERRIDE_NONE;
 }
 
 // Copies a pref override file into the user's profile pref-override folder,
@@ -195,14 +204,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 203 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 215 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 210 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 222 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -215,7 +224,7 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 235 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 247 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -275,6 +284,7 @@ var nsBrowserContentHandler = {
         !iid.equals(nsICommandLineHandler) &&
         !iid.equals(nsIBrowserHandler) &&
         !iid.equals(nsIContentHandler) &&
+        !iid.equals(nsICommandLineValidator) &&
         !iid.equals(nsIFactory))
       throw Components.errors.NS_ERROR_NO_INTERFACE;
 
@@ -402,12 +412,28 @@ var nsBrowserContentHandler = {
       // Handle the old preference dialog URL separately (bug 285416)
       if (chromeParam == "chrome://browser/content/pref/pref.xul") {
         openPreferences();
-      } else {
-        var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
-        openWindow(null, chromeParam, "_blank", features, "");
-      }
+        cmdLine.preventDefault = true;
+      } else try {
+        // only load URIs which do not inherit chrome privs.
 
-      cmdLine.preventDefault = true;
+        // normally would call checkLoadURI(..., DISALLOW_SCRIPT_OR_DATA)
+        // for this, but in this context we crash when the security manager
+        // tries to throw an exception (no window object here). On the branch
+        // we need to simulate the important bits
+        var uri = resolveURIInternal(cmdLine, chromeParam);
+        while (uri instanceof nsIJARURI) {
+          // unpack to find the real scheme
+          uri = uri.JARFile;
+        }
+        if (!uri.schemeIs("javascript") && !uri.schemeIs("data")) {
+          var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
+          openWindow(null, uri.spec, "_blank", features, "");
+          cmdLine.preventDefault = true;
+        }
+      }
+      catch (e) {
+        Components.utils.reportError(e);
+      }
     }
     if (cmdLine.handleFlag("preferences", false)) {
       openPreferences();
@@ -422,7 +448,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 454 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 483 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -435,43 +461,53 @@ var nsBrowserContentHandler = {
     var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
                               .getService(Components.interfaces.nsIURLFormatter);
 
-    var pagesToLoad = "";
-    var overrideState = needHomepageOverride(prefb);
+    var overridePage = "";
+    var haveUpdateSession = false;
     try {
-      if (overrideState == 1) {
-        // New profile.
-        pagesToLoad = formatter.formatURLPref("startup.homepage_welcome_url");
-      }
-      else if (overrideState == 2) {
-        // Existing profile.
-        copyPrefOverride();
+      switch (needHomepageOverride(prefb)) {
+        case OVERRIDE_NEW_PROFILE:
+          // New profile.
+          overridePage = formatter.formatURLPref("startup.homepage_welcome_url");
+          break;
+        case OVERRIDE_NEW_MSTONE:
+          // Existing profile.
+          copyPrefOverride();
 
-        pagesToLoad = formatter.formatURLPref("startup.homepage_override_url");
+          // Check whether we have a session to restore. If we do, we assume
+          // that this is an "update" session.
+          var ss = Components.classes["@mozilla.org/browser/sessionstartup;1"]
+                             .getService(Components.interfaces.nsISessionStartup);
+          haveUpdateSession = ss.doRestore();
+          overridePage = formatter.formatURLPref("startup.homepage_override_url");
+          break;
       }
-    }
-    catch (e) {
-    }
+    } catch (e) {}
 
-    var startpage = "";
+    // formatURLPref might return "about:blank" if getting the pref fails
+    if (overridePage == "about:blank")
+      overridePage = "";
+
+    var startPage = "";
     try {
       var choice = prefb.getIntPref("browser.startup.page");
       if (choice == 1)
-        startpage = this.startPage;
+        startPage = this.startPage;
 
       if (choice == 2)
-        startpage = Components.classes["@mozilla.org/browser/global-history;2"]
+        startPage = Components.classes["@mozilla.org/browser/global-history;2"]
                               .getService(nsIBrowserHistory).lastPageVisited;
-    }
-    catch (e) {
+    } catch (e) {
+      Components.utils.reportError(e);
     }
 
-    if (startpage == "about:blank")
-      startpage = "";
+    if (startPage == "about:blank")
+      startPage = "";
 
-    if (pagesToLoad && startpage) pagesToLoad += "|";
-    pagesToLoad += startpage;
-
-    return (pagesToLoad ?  pagesToLoad : "about:blank");
+    // Only show the startPage if we're not restoring an update session.
+    if (overridePage && startPage && !haveUpdateSession)
+      return overridePage + "|" + startPage;
+ 
+    return overridePage || startPage || "about:blank";
   },
 
   get startPage() {
@@ -556,6 +592,21 @@ var nsBrowserContentHandler = {
     request.cancel(NS_BINDING_ABORTED);
   },
 
+  /* nsICommandLineValidator */
+  validate : function bch_validate(cmdLine) {
+    // Other handlers may use osint so only handle the osint flag if the url
+    // flag is also present and the command line is valid.
+    var osintFlagIdx = cmdLine.findFlag("osint", false);
+    var urlFlagIdx = cmdLine.findFlag("url", false);
+    if (urlFlagIdx > -1 && (osintFlagIdx > -1 ||
+        cmdLine.state == nsICommandLine.STATE_REMOTE_EXPLICIT)) {
+      var urlParam = cmdLine.getArgument(urlFlagIdx + 1);
+      if (cmdLine.length != urlFlagIdx + 2 || /firefoxurl:/.test(urlParam))
+        throw NS_ERROR_ABORT;
+      cmdLine.handleFlag("osint", false)
+    }
+  },
+
   /* nsIFactory */
   createInstance: function bch_CI(outer, iid) {
     if (outer != null)
@@ -613,13 +664,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 647 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 701 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 673 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 727 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -769,7 +820,7 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 825 "/export/home/mozilla/uild/firefox-2.0.0.3/src/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 879 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
@@ -794,6 +845,9 @@ var Module = {
     catMan.addCategoryEntry("command-line-handler",
                             "x-default",
                             dch_contractID, true, true);
+    catMan.addCategoryEntry("command-line-validator",
+                            "b-browser",
+                            bch_contractID, true, true);
   },
     
   unregisterSelf : function mod_unregself(compMgr, location, type) {
@@ -808,6 +862,8 @@ var Module = {
                                "m-browser", true);
     catMan.deleteCategoryEntry("command-line-handler",
                                "x-default", true);
+    catMan.deleteCategoryEntry("command-line-validator",
+                               "b-browser", true);
   },
 
   canUnload: function(compMgr) {
