@@ -1,4 +1,4 @@
-//@line 40 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -462,9 +462,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 509 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 509 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 512 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 512 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -852,7 +852,10 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 903 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 903 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/content/contentAreaUtils.js"
+
+  // Remove leading dots
+  aFile = aFile.replace(/^\.+/, "");
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
