@@ -109,7 +109,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 113 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 113 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -117,7 +117,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 124 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 124 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -310,6 +310,7 @@ pref("capability.policy.mailnews.*.attributes.get", "noAccess");
 pref("capability.policy.mailnews.*.baseURI.get", "noAccess");
 pref("capability.policy.mailnews.*.data.get", "noAccess");
 pref("capability.policy.mailnews.*.getAttribute", "noAccess");
+pref("capability.policy.mailnews.HTMLDivElement.getAttribute", "sameOrigin");
 pref("capability.policy.mailnews.*.getAttributeNS", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItem", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItemNS", "noAccess");
@@ -486,7 +487,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 495 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 496 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -683,7 +684,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 697 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 698 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -831,7 +832,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 879 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 880 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -848,7 +849,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 896 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 897 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -991,15 +992,15 @@ pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
 
-//@line 1369 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 1370 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1561 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 1562 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1750 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 1751 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1839 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 1840 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1842 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 1843 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1072,7 +1073,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1975 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 1976 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 pref("font.name.serif.el", "misc-fixed-iso8859-7");
 pref("font.name.sans-serif.el", "misc-fixed-iso8859-7");
 pref("font.name.monospace.el", "misc-fixed-iso8859-7");
@@ -1130,7 +1131,7 @@ pref("font.name.sans-serif.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 pref("font.name.monospace.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 
 // zh-TW
-//@line 2034 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 2035 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1348,15 +1349,15 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2254 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 2255 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2322 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 2323 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2348 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 2349 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2368 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 2369 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2370 "/export/home/mozilla/uild/firefox2.0/mozilla/modules/libpref/src/init/all.js"
+//@line 2371 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+'-d '}${MOZ_PRINTER_NAME}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+'-d '}${MOZ_PRINTER_NAME}");
