@@ -1,4 +1,4 @@
-//@line 38 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 38 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -94,7 +94,7 @@ function showMessage(aIconURL, aMessage, aButtonLabel, aButtonAccesskey,
   if (aButtonLabel)
     buttons = [new MessageButton(aButtonLabel, aButtonAccesskey, aNotifyData)];
   var oldMessage = addonsMsg.getNotificationWithValue(aMessage);
-  if (oldMessage)
+  if (oldMessage && oldMessage.parentNode)
     addonsMsg.removeNotification(oldMessage);
   if (addonsMsg.currentNotification)
     gPriorityCount += 0.0001;
@@ -424,7 +424,7 @@ function getIDFromResourceURI(aURI)
 
 function openURL(aURL)
 {
-//@line 473 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 473 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
   // bug 262575
   if (window.opener && window.opener.openUILinkIn) {
     var newWindowPref = gPref.getIntPref("browser.link.open_newwindow");
@@ -432,7 +432,7 @@ function openURL(aURL)
     window.opener.openUILinkIn(aURL, where);
   } else
     openDialog("chrome://browser/content/browser.xul", "_blank", "chrome,all,dialog=no", aURL, null, null);
-//@line 481 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 481 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 }
 
 function showProgressBar() {
@@ -454,8 +454,6 @@ function flushDataSource()
 function noUpdatesDismiss(aEvent)
 {
   window.removeEventListener("command", noUpdatesDismiss, true);
-  if (aEvent.target.localName != "notification")
-    return;
 
   var children = gExtensionsView.children;
   for (var i = 0; i < children.length; ++i) {
@@ -463,6 +461,9 @@ function noUpdatesDismiss(aEvent)
     if (child.hasAttribute("updateStatus"))
       child.removeAttribute("updateStatus");
   }
+
+  if (aEvent.target.localName != "notification")
+    document.getElementById("addonsMsg").removeCurrentNotification();
 }
 
 function setRestartMessage(aItem)
@@ -1126,7 +1127,7 @@ var gExtensionsDNDObserver =
     // XXXrstrong - bug 269568, GTK2 drag and drop is returning invalid data for
     // dragenter and dragover. To workaround this we always set canDrop to true
     // and just use the xfer data returned in ondrop which is valid.
-//@line 1175 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 1176 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     this._ensureServices();
 
     var count = aDragSession.numDropItems;
@@ -1137,7 +1138,7 @@ var gExtensionsDNDObserver =
         return;
       }
     }
-//@line 1186 "/export/home/mozilla/uild/firefox2.0/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 1187 "/export/home/mozilla/uild/firefox-2.0.0.7/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     this._canDrop = true;
   },
 
